Python Turtle Graphics
::::::::::::::::::::::

.. toctree::
   :caption: Python Turtle Graphics
   :maxdepth: 2

   intro-HelloLittleTurtles.rst
   OurFirstTurtleProgram.rst
   InstancesAHerdofTurtles.rst
   TheforLoop.rst
   FlowofExecutionoftheforLoop.rst
   IterationSimplifiesourTurtleProgram.rst
   TherangeFunction.rst
   AFewMoreturtleMethodsandObservations.rst
   SummaryofTurtleMethods.rst
   Glossary.rst
   Exercises.rst
